<template>
  <ContentScrollView :paddingH="false">
    <nut-form :model-value="form" ref="formRef" :rules="rules">
      <nut-form-item label="任务名称:" class="bole-form-item" prop="name" label-width="90px">
        <nut-input v-model="form.name" placeholder="请输入任务名称"> </nut-input>
      </nut-form-item>
      <nut-form-item
        label="服务费:"
        class="bole-form-item"
        prop="salaryTimeType"
        required
        label-width="90px"
      >
        <nut-radio-group v-model="form.salaryTimeType" direction="horizontal">
          <BlRadio :label="Number(key)" v-for="(val, key) in SalaryTimeTypeEnumText" :key="key">{{
            val
          }}</BlRadio>
        </nut-radio-group>
      </nut-form-item>
      <nut-form-item label=" " class="bole-form-item" prop="welfare" label-width="90px">
        <div class="bole-form-input-wrapper">
          <nut-input
            v-model.trim="form.welfare"
            class="nut-input-text bole-input-text"
            placeholder="请输入服务费"
            type="text"
          />
          <div class="form-input-unit">{{ SalaryTimeTypeEnumUnit[form.salaryTimeType] }}</div>
        </div>
      </nut-form-item>
      <nut-form-item
        label="结算方式:"
        class="bole-form-item"
        prop="salaryType"
        required
        label-width="90px"
      >
        <nut-radio-group v-model="form.salaryType" direction="horizontal">
          <BlRadio :label="Number(key)" v-for="(val, key) in SalaryTypeText">{{ val }}</BlRadio>
        </nut-radio-group>
      </nut-form-item>
      <nut-form-item label="福利:" class="bole-form-item" prop="welfare" label-width="90px">
        <ChooseInputWithPicker
          v-model="form.welfare"
          placeholder="请选择福利"
          :value-enum="TaskStatusText"
        />
      </nut-form-item>
      <nut-form-item
        label="年龄范围:"
        class="bole-form-item"
        prop="ageStart"
        required
        label-width="90px"
      >
        <div class="bole-form-input-wrapper">
          <NumberInput
            v-model.trim="form.ageStart"
            class="nut-input-text bole-input-text"
            placeholder="请选择年龄范围"
            :min="1"
          />
          <div class="form-input-separator">至</div>
          <NumberInput
            v-model.trim="form.ageEnd"
            class="nut-input-text bole-input-text"
            placeholder="请选择年龄范围"
            :min="1"
          />
        </div>
      </nut-form-item>
      <nut-form-item label="性别:" class="bole-form-item" prop="welfare" label-width="90px">
        <ChooseInputWithPicker
          v-model="form.welfare"
          placeholder="请选择性别要求"
          :value-enum="TaskStatusText"
        />
      </nut-form-item>
      <nut-form-item label="资格证书:" class="bole-form-item" prop="welfare" label-width="90px">
        <ChooseInputWithPicker
          v-model="form.welfare"
          placeholder="请选择要求的资格证书"
          :value-enum="TaskStatusText"
        />
      </nut-form-item>
      <nut-form-item label="任务地点" class="bole-form-item" prop="weMapInfo" required>
        <ChooseLocationInput placeholder="请选择任务所在地" v-model="form.weMapInfo" />
      </nut-form-item>
      <nut-form-item label="详细地址:" class="bole-form-item" prop="name" label-width="90px">
        <nut-input v-model="form.name" placeholder="请输入详细地址"> </nut-input>
      </nut-form-item>
      <nut-form-item
        label="任务开始日期:"
        class="bole-form-item"
        prop="startDate"
        label-width="90px"
      >
        <ChooseInputWithDatePicker v-model="form.startDate"></ChooseInputWithDatePicker>
      </nut-form-item>
      <nut-form-item label="任务结束日期:" class="bole-form-item" prop="endDate" label-width="90px">
        <ChooseInputWithDatePicker v-model="form.endDate"></ChooseInputWithDatePicker>
      </nut-form-item>
    </nut-form>
  </ContentScrollView>
  <PageFooter>
    <PageFooterBtn type="primary" plain @click="handleCancel">取消</PageFooterBtn>
    <PageFooterBtn type="primary" @click="handleConfirm">发布</PageFooterBtn>
  </PageFooter>
</template>

<script setup lang="ts">
import {
  TaskStatus,
  TaskStatusText,
  SalaryTypeText,
  SalaryType,
  SalaryTimeTypeEnum,
  SalaryTimeTypeEnumText,
  SalaryTimeTypeEnumUnit,
} from '@/constants/task';
import { useUser } from '@/hooks';
import {
  ChooseInputWithPicker,
  ChooseInputWithDatePicker,
  NumberInput,
  ChooseLocationInput,
  Radio as BlRadio,
} from '@12333/components';
import { FormValidator } from '@12333/utils';
import { FormRules } from '@nutui/nutui-taro/dist/types/__VUE/form/types';
import Taro from '@tarojs/taro';

defineOptions({
  name: 'InnerPage',
});

const { userDetail } = useUser();

const form = reactive({
  name: '',
  welfare: TaskStatus.All,
  salaryTimeType: SalaryTimeTypeEnum.Month,
  salaryType: SalaryType.month,
  startDate: '',
  endDate: '',
  ageStart: '',
  ageEnd: '',
  weMapInfo: {} as WeMapModel,
});

const rules = reactive<FormRules>({
  name: [{ required: true, message: '请输入任务名称' }],

  weMapInfo: [
    { required: true, message: '请设置工作地点', validator: FormValidator.validatorWeMap },
  ],

  ageStart: [
    {
      required: true,
      message: '请输入年龄要求',
      validator: () => {
        if (!form.ageStart) {
          return Promise.reject('请输入年龄要求');
        }
        if (!form.ageEnd) {
          return Promise.reject('请输入年龄要求');
        }
        if (Number(form.ageEnd) <= Number(form.ageStart)) {
          return Promise.reject('最大年龄不能小于最小年龄');
        }
        return Promise.resolve(true);
      },
    },
  ],
});
const formRef = ref<any>(null);
function handleConfirm() {
  if (!formRef.value) return;
  formRef.value.validate().then(({ valid, errors }: any) => {
    if (valid) {
      confirm();
    }
  });
}

function confirm() {}

function handleCancel() {
  Taro.navigateBack();
}
</script>

<style lang="scss">
@import '@/styles/common.scss';

.publishTask-page-wrapper {
  .bole-form-input-wrapper {
    display: flex;
    align-items: center;
  }

  .form-input-unit {
    margin-left: 10px;
    color: boleGetCssVar('text-color', 'primary');
    flex-shrink: 0;
  }
}
</style>
